Cluster templates
=================

Templates is an attempt to provide a simple unified mean of Hadoop cluster configuration.
See the wiki link for more details

`Read full specification here <https://wiki.openstack.org/wiki/Savanna/Templates>`_.


.. note::

    Details of templates mechanism will be moved here once this functionality is is checked into repository.